package com.ruoyi.generator.service;

import java.util.List;
import com.ruoyi.generator.domain.SysProjectTemplate;

/**
 * 项目模板配置Service接口
 * 
 * @author ruoyi
 * @date 2025-05-09
 */
public interface ISysProjectTemplateService 
{
    /**
     * 查询项目模板配置
     * 
     * @param id 项目模板配置主键
     * @return 项目模板配置
     */
    public SysProjectTemplate selectSysProjectTemplateById(Long id);

    /**
     * 查询项目模板配置
     *
     * @param id 项目模板配置主键
     * @return 项目模板配置
     */
    public SysProjectTemplate selectSysProjectTemplateByProjectAndType(Long projectId, String templateType);

    /**
     * 查询项目模板配置列表
     * 
     * @param sysProjectTemplate 项目模板配置
     * @return 项目模板配置集合
     */
    public List<SysProjectTemplate> selectSysProjectTemplateList(SysProjectTemplate sysProjectTemplate);

    /**
     * 新增项目模板配置
     * 
     * @param sysProjectTemplate 项目模板配置
     * @return 结果
     */
    public int insertSysProjectTemplate(SysProjectTemplate sysProjectTemplate);

    /**
     * 修改项目模板配置
     * 
     * @param sysProjectTemplate 项目模板配置
     * @return 结果
     */
    public int updateSysProjectTemplate(SysProjectTemplate sysProjectTemplate);

    /**
     * 批量删除项目模板配置
     * 
     * @param ids 需要删除的项目模板配置主键集合
     * @return 结果
     */
    public int deleteSysProjectTemplateByIds(Long[] ids);

    public int deleteSysProjectTemplateByProjectId(Long projectId);

    /**
     * 删除项目模板配置信息
     * 
     * @param id 项目模板配置主键
     * @return 结果
     */
    public int deleteSysProjectTemplateById(Long id);

    /**
     * 根据项目ID查询项目模板配置列表
     *
     * @param projectId 项目ID
     * @return 项目模板配置集合
     */
    public List<SysProjectTemplate> selectSysProjectTemplateListByProjectId(Long projectId);
}
